Queue

Struct Queue 

pub struct Queue { /* private fields */ }
The queue itself, which consists of the SQLite connection and tasks to monitor running jobs.

Implementations

Source

impl Queue

pub async fn add_job(&self, job_config: Job) -> Result<Uuid>

Submit a job to the queue

pub async fn add_jobs(&self, jobs: Vec<Job>) -> Result<Vec<Uuid>>

Submit multiple jobs to the queue

Source

impl Queue

pub async fn get_job_status(&self, external_id: Uuid) -> Result<JobStatus>

Return information about a job

pub async fn num_active_jobs(&self) -> Result<NumActiveJobs>

Return counts about the number of jobs running and waiting to run.

Source

impl Queue

pub async fn new(file: &Path) -> Result<Queue>

Open or create a Queue database at the given path.

pub fn builder(path: &Path) -> QueueOptions<'_>

Create a builder object for a Queue

pub async fn with_options(options: QueueOptions<'_>) -> Result<Queue>

Open or create a Queue database with the given [LocalQueueOptions].

pub async fn close(&self, timeout: Duration) -> Result<()>

Stop the queue, and wait for existing workers to finish.