QueueOptions

Struct QueueOptions 

pub struct QueueOptions<'a> { /* private fields */ }
Options used to configure a Queue instance.

Implementations

Source

impl<'a> QueueOptions<'a>

pub fn new(path: &'a Path) -> Self

Create a new options object for a Queue

pub fn job_recovery_behavior(self, behavior: JobRecoveryBehavior) -> Self

Configure how the Queue treats jobs that were already marked as runnning when the it starts. This usually indicates jobs that were left unfinished due to an unexpected process restart.

pub async fn build(self) -> Result<Queue>

Build a Queue from this options object.