pub struct QueueOptions<'a> { /* private fields */ }Expand description
Options used to configure a Queue instance.
Implementations
Sourceimpl<'a> QueueOptions<'a>
impl<'a> QueueOptions<'a>
Sourcepub fn job_recovery_behavior(self, behavior: JobRecoveryBehavior) -> Self
pub fn job_recovery_behavior(self, behavior: JobRecoveryBehavior) -> Self
Configure how the Queue treats jobs that were already marked as runnning when the it starts. This usually indicates jobs that were left unfinished due to an unexpected process restart.